# Generated by roxygen2: do not edit by hand

export(aggregate_by_manager)
export(analyze_attrition)
export(analyze_by_attributes)
export(compare_cycles)
export(extract_questions)
export(extract_survey_factors)
export(get_correlations)
export(get_response_dist)
export(glint_setup)
export(join_attributes)
export(pivot_long)
export(read_glint_survey)
export(read_glint_survey_api)
export(search_comments)
export(split_survey_data)
export(summarize_survey)
importFrom(dplyr,"%>%")
importFrom(stats,cor)
importFrom(stats,cor.test)
importFrom(stats,sd)
importFrom(stats,setNames)
