#' @importFrom dplyr %>%
#' @importFrom stats cor cor.test sd setNames
#' @keywords internal
"_PACKAGE"

utils::globalVariables(c(
	".data",
	"First Name",
	"Last Name",
	"comment",
	"comment_topics",
	"communality",
	"correlation",
	"cycle",
	"factor",
	"glint_score",
	"group_size",
	"loading",
	"loading_label",
	"manager_id",
	"manager_name",
	"n",
	"p_value",
	"pct",
	"question",
	"question1",
	"question2",
	"response",
	"sensitive_flag",
	"sentiment",
	"team_size",
	"value"
))

## usethis namespace: start
## usethis namespace: end
NULL
