% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/analyze.R
\name{expand_value_distributions}
\alias{expand_value_distributions}
\title{Expand Value Distributions}
\usage{
expand_value_distributions(analysis_df)
}
\arguments{
\item{analysis_df}{A tibble from get_response_dist() with value_counts and value_percents list columns}
}
\value{
A tibble with expanded columns for each response value
}
\description{
Internal function to expand value_counts and value_percents list columns
into separate columns for each response value.
}
\keyword{internal}
